@@ -715,6 +715,13 @@ char* readline_program_completion(const char* text, int stat)
         index++;
 
         if(!strncmp(text, program, wordlen)) {
+            int l = strlen(program);
+            if(l >= 2 && program[l-2] == '-' && program[l-1] == '>') {
+                rl_completion_append_character= 0;
+            }
+            else {
+                rl_completion_append_character= ' ';
+            }
             return strdup(program);
         }
     }
@@ -722,6 +729,29 @@ char* readline_program_completion(const char* text, int stat)
     return NULL;
 }
 
+static vector_obj* gMethodCompletions;
+
+char* readline_method_completion(const char* text, int stat)
+{
+    static int index, wordlen;
+
+    if(stat == 0) {
+        wordlen = strlen(text);
+        index = 0;
+    }
+
+    while(index < vector_size(gMethodCompletions)) {
+        char* method = string_c_str(vector_item(gMethodCompletions, index));
+        index++;
+
+        if(!strncmp(text, method, wordlen)) {
+            return strdup(method);
+        }
+    }
+
+    return NULL;
+}
+
 char* readline_file_completion(const char* text, int rstat)
 {
     /// クォートを除外 ///
@@ -976,6 +1006,9 @@ char** readline_on_complete(const char* text, int start, int end)
 {
     BOOL program = TRUE;
     BOOL user = FALSE;
+    BOOL method = FALSE;
+
+    string_obj* buf = STRING_NEW("");
 
     char* p = rl_line_buffer;
 
@@ -990,18 +1023,26 @@ char** readline_on_complete(const char* text, int start, int end)
         if(*p == '\\' && *(p+1) == 't') {
             p+=2;
             user = FALSE;
+
+            string_put(buf, "");
         }
         else if(*p == '\\' && *(p+1) == 'n') {
             p+=2;
             user = FALSE;
+
+            string_put(buf, "");
         }
         else if(*p == '\\' && *(p+1) == 'r') {
             p+=2;
             user = FALSE;
+
+            string_put(buf, "");
         }
         else if(*p == '\\') {
             p+=2;
             user = FALSE;
+
+            string_put(buf, "");
         }
 
         // シングルクォート
@@ -1009,12 +1050,16 @@ char** readline_on_complete(const char* text, int start, int end)
             p++;
             squote = !squote;
             user = FALSE;
+
+            string_put(buf, "");
         }
         // ダブルクォート
         else if(!squote && *p == '"') {
             p++;
             dquote = !dquote;
             user = FALSE;
+
+            string_put(buf, "");
         }
         // 環境変数 $$()
         else if(!squote && *p == '$' && *(p+1) == '$' && *(p+2) == '(') {
@@ -1026,6 +1071,8 @@ char** readline_on_complete(const char* text, int start, int end)
                 p++;
             }
             user = FALSE;
+
+            string_put(buf, "");
         }
         // 環境変数 $()
         else if(!squote && *p == '$' && *(p+1) == '(') {
@@ -1036,6 +1083,8 @@ char** readline_on_complete(const char* text, int start, int end)
                 p++;
             }
             user = FALSE;
+
+            string_put(buf, "");
         }
         else if(!dquote && !squote && *p == ')') {
             p++;
@@ -1044,55 +1093,81 @@ char** readline_on_complete(const char* text, int start, int end)
                 p++;
             }
             user = FALSE;
+
+            string_put(buf, "");
         }
 
         // 環境変数 $$
         else if(!squote && *p == '$' && *(p+1) == '$') {
             p+=2;
             user = FALSE;
+
+            string_put(buf, "");
         }
         // 環境変数 $
         else if(!squote && *p == '$') {
             p++;
             user = FALSE;
+
+            string_put(buf, "");
         }
 
         // 環境変数 @
         else if(!squote && *p == '@' && *(p+1) == '@') {
             p+=2;
             user = FALSE;
+
+            string_put(buf, "");
         }
         // 環境変数 @@
         else if(!squote && *p == '@') {
             p++;
             user = FALSE;
+
+            string_put(buf, "");
         }
         /// シングルクォート、ダブルクォート中 ///
         else if(squote || dquote) {
             p++;
+
+            string_put(buf, "");
         }
         else if(*p == '~') {
             p++;
             user = TRUE;
+
+            string_put(buf, "");
         }
         /// グロブ ///
         else if(*p == '*' || *p == '?' || *p =='[' && (*(p+1) != ' ' && *(p+1) != '\t' && *(p+1) == '\n')) 
         {
             p++;
             user = FALSE;
+
+            string_put(buf, "");
         }
-/*
         else if(*p == '-' && *(p+1) == '>') {
             p+=2;
-            program = TRUE;
+            if(program) { 
+                sObject* object = saphire_get_object(string_c_str(buf));
+
+                if(object) {
+                    gMethodCompletions = saphire_methods_names(object);
+                    method = TRUE; 
+                    program = FALSE;  
+                }
+                string_put(buf, "");
+            }
+
             user = FALSE;
         }
-*/
         else if(*p == '<' && program) {
             p++;
 
             program = FALSE;
             user = FALSE;
+
+            string_put(buf, "");
         }
         /// 単語の区切り /////////////////////////////////////////////////
     
@@ -1102,17 +1177,23 @@ char** readline_on_complete(const char* text, int start, int end)
                 p++;
             }
 
-            if(program) program = FALSE;
+            program = FALSE;
+            method = FALSE;
             user = FALSE;
+
+            string_put(buf, "");
         }
         /// ブロック
-        else if(*p == ':' || *p == '{') {
+        else if(*p == '{') {
             p++;
             program = TRUE;
+            method = FALSE;
             while(*p == ' ' || *p == '\t' || *p == '\n') {
                 p++;
             }
             user = FALSE;
+
+            string_put(buf, "");
         }
         
         /// コマンドの区切り ///////////////////////////////////////////
@@ -1122,10 +1203,13 @@ char** readline_on_complete(const char* text, int start, int end)
             p+=2;
 
             program = TRUE;
+            method = FALSE;
             while(*p == ' ' || *p == '\t' || *p == '\n') {
                 p++;
             }
             user = FALSE;
+
+            string_put(buf, "");
         }
         
         /// パイプ ///
@@ -1133,10 +1217,13 @@ char** readline_on_complete(const char* text, int start, int end)
             p++;
 
             program = TRUE;
+            method = FALSE;
             while(*p == ' ' || *p == '\t' || *p == '\n') {
                 p++;
             }
             user = FALSE;
+
+            string_put(buf, "");
         }
         
         /// 文(statment)の区切り系 ///////////////////////////////////
@@ -1146,50 +1233,65 @@ char** readline_on_complete(const char* text, int start, int end)
             p+=2;
 
             program = TRUE;
+            method = FALSE;
             while(*p == ' ' || *p == '\t' || *p == '\n') {
                 p++;
             }
             user = FALSE;
+
+            string_put(buf, "");
         }
         /// オアオア ///
         else if(*p == '|' && *(p+1) == '|') {
             p+=2;
 
             program = TRUE;
+            method = FALSE;
             while(*p == ' ' || *p == '\t' || *p == '\n') {
                 p++;
             }
             user = FALSE;
+
+            string_put(buf, "");
         }
         /// バックグラウンド ///
         else if(*p == '&' && *(p+1) != '&') {
             p++;
 
             program = TRUE;
+            method = FALSE;
             while(*p == ' ' || *p == '\t' || *p == '\n') {
                 p++;
             }
             user = FALSE;
+
+            string_put(buf, "");
         }
         /// セミコロン ///
         else if(*p == ';') {
             p++;
 
             program = TRUE;
+            method = FALSE;
             while(*p == ' ' || *p == '\t' || *p == '\n') {
                 p++;
             }
             user = FALSE;
+
+            string_put(buf, "");
         }
         /// 改行 ///
         else if(*p == '\n') {
             p++;
 
             program = TRUE;
+            method = FALSE;
             while(*p == ' ' || *p == '\t' || *p == '\n') {
                 p++;
             }
             user = FALSE;
+
+            string_put(buf, "");
         }
         /// コメント ///
         else if(*p == '#') {
@@ -1209,11 +1311,17 @@ char** readline_on_complete(const char* text, int start, int end)
                 p++;
             }
             user = FALSE;
+            method = FALSE;
+
+            string_put(buf, "");
         }
         else if(*p == '/') {
             user = FALSE;
             program = FALSE;
+            method = FALSE;
             p++;
+
+            string_put(buf, "");
         }
         /// 終了 ///
         else if(*p == 0) {
@@ -1226,12 +1334,16 @@ char** readline_on_complete(const char* text, int start, int end)
         else if(*p == '(') {
             p++;
             program = TRUE;
+            method = FALSE;
             user = FALSE;
             while(*p == ' ' || *p == '\t' || *p == '\n') {
                 p++;
             }
+
+            string_put(buf, "");
         }
         else {
+            string_push_back2(buf, *p);
             p++;
         }
     }
@@ -1244,6 +1356,10 @@ char** readline_on_complete(const char* text, int start, int end)
         rl_completion_append_character= ' ';
         return rl_completion_matches(text, readline_program_completion);
     }
+    else if(method) {
+        rl_completion_append_character= ' ';
+        return rl_completion_matches(text, readline_method_completion);
+    }
 #if defined(HAVE_MIGEMO_H)
     else {
         return rl_completion_matches(text, readline_file_completion_migemo);
@@ -1671,6 +1787,7 @@ void readline_init()
 #endif
 
     gEditingDir = STRING_NEW("");
+    gMethodCompletions = NULL;
 
     rl_bind_key('x'-'a'+1, readline_select_file);
 }
