@@ -49,6 +49,7 @@ typedef struct _sObject {
     hash_obj* mArrays;
     hash_obj* mObjects;
     hash_obj* mClasses;
+    hash_obj* mPointers;
 
     struct _sObject* mParent;
 
@@ -63,6 +64,15 @@ sObject* saphire_get_object(char* name);
 vector_obj* saphire_methods_names(sObject* object);
     // 引数のオブジェクトのメソッドの一覧を返す
 
+typedef struct {
+    string_obj* mName;               /// 自分の名前
+    string_obj* mPointer;
+    char* mP;
+} sPointer;
+
+sPointer* sPointer_new(char* name, string_obj* pointer);
+BOOL sPointer_inc(sPointer* self, int n, enum eKanjiCode code);
+
 typedef struct {
     int mFd;
     char* mBuffer;
@@ -193,6 +203,9 @@ extern hash_obj* gHashs;
     // グローバル変数の配列 キーは変数名
     // 内容はハッシュ(hash_obj*) ハッシュの中にはstring_obj*
     // が入っている
+extern hash_obj* gPointers;
+    // ポインター キーは変数名
+    // 内容はsPonter*
 
 void saphire_rehash();
     // プログラム補完候補の一覧の再読み込み
