@@ -9,6 +9,7 @@ extern volatile BOOL gSigUser;
 /// ޥɤбʸ
 enum eCommandKind { 
     kObject,
+    kPointer,
     kVar, kGlobal, kExport, 
     kAry, kAryAdd, kAryErase, 
     kHash, kHashAdd, kHashErase,  
@@ -78,6 +79,9 @@ extern hash_obj* gClasses;
     // ϥ饹̾
 
 extern vector_obj* gStackFrame;
+extern vector_obj* gStackFramePointers;
+extern vector_obj* gStackFrameArrays;
+extern vector_obj* gStackFrameHashs;
     // ѿΥå
     // Ƥhash_obj*
     // Υϥѿ̾
