@@ -36,7 +36,7 @@ enum eKanjiCode gKanjiCode = kUtf8;
 
 
 char* gStatmentKindStrs[kCommand+1] = {
-    "object", "var", "global", "export", 
+    "object", "pointer", "var", "global", "export", 
     "ary", "ary_add", "ary_erase", 
     "hash", "hash_add", "hash_erase",
     "def", "inherit", "class",
@@ -116,8 +116,13 @@ hash_obj* gHashs;
     // グローバル変数の配列 キーは変数名
     // 内容はハッシュ(hash_obj*) ハッシュの中にはstring_obj*
     // が入っている
+hash_obj* gPointers;
+    // ポインター キーは変数名
 
 vector_obj* gStackFrame;
+vector_obj* gStackFramePointers;
+vector_obj* gStackFrameArrays;
+vector_obj* gStackFrameHashs;
     // ローカル変数のスタック
     // 内容はhash_obj*
     // これのキーはローカル変数名
@@ -195,6 +200,7 @@ sObject* sObject_new(char* name, sObject* parent)
     self->mArrays = HASH_NEW(15);
     self->mObjects = HASH_NEW(15);
     self->mClasses = HASH_NEW(15);
+    self->mPointers = HASH_NEW(15);
 
     self->mParent = parent;
 
@@ -405,6 +411,12 @@ void saphire_init_stack_frame()
 {
     vector_clear(gStackFrame);
     vector_add(gStackFrame, HASH_NEW(30));
+    vector_clear(gStackFramePointers);
+    vector_add(gStackFramePointers, HASH_NEW(30));
+    vector_clear(gStackFrameArrays);
+    vector_add(gStackFrameArrays, HASH_NEW(30));
+    vector_clear(gStackFrameHashs);
+    vector_add(gStackFrameHashs, HASH_NEW(30));
 }
 
 void saphire_set_global_var(char* name, char* value)
@@ -2603,6 +2615,7 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
     gHashs = HASH_NEW(100);
     gFuncs = HASH_NEW(50);
     gClasses = HASH_NEW(50);
+    gPointers = HASH_NEW(50);
 
     gJobs = VECTOR_NEW(50);
 
@@ -2612,7 +2625,7 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
 
     gReadBuffers = HASH_NEW(100);
 
-    setenv("SAPHIRE_VERSION", "3.3.1", 1);
+    setenv("SAPHIRE_VERSION", "3.3.2", 1);
     setenv("SAPHIRE_PROMPT", "> ", 1);
     setenv("SAPHIRE_DOCDIR", DOCDIR, 1);
     char* home = getenv("HOME");
@@ -2639,6 +2652,12 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
     
     gStackFrame = VECTOR_NEW(5);
     vector_add(gStackFrame, HASH_NEW(30));
+    gStackFrameArrays = VECTOR_NEW(5);
+    vector_add(gStackFrameArrays, HASH_NEW(30));
+    gStackFramePointers = VECTOR_NEW(5);
+    vector_add(gStackFramePointers, HASH_NEW(30));
+    gStackFrameHashs = VECTOR_NEW(5);
+    vector_add(gStackFrameHashs, HASH_NEW(30));
 
     gInnerCommands = HASH_NEW(50);
     gKitutukiExit = -1;
@@ -3544,6 +3563,18 @@ void saphire_make_var_completion_list()
         it = hash_loop_next(it);
     }
 
+    it = hash_loop_begin(gPointers);
+    while(it) {
+        char* key = hash_loop_key(it);
+
+        char env_name[1024];
+        xstrncpy(env_name, key, 1024);
+
+        vector_add(gSaphireVarCompletions, STRING_NEW(env_name));
+
+        it = hash_loop_next(it);
+    }
+
     (void)vector_sort(gSaphireVarCompletions, name_sort);
 }
 
@@ -3672,3 +3703,22 @@ sObject* saphire_get_object(char* name)
 {
     return hash_item(gObjects, name);
 }
+
+sPointer* sPointer_new(char* name, string_obj* pointer)
+{
+    sPointer* self = MALLOC(sizeof(sPointer));
+    
+    self->mName = STRING_NEW(name);
+    self->mPointer = pointer;
+    self->mP = string_c_str(pointer);
+
+    return self;
+}
+
+BOOL sPointer_inc(sPointer* self, int n, enum eKanjiCode code)
+{
+    self->mP = str_kanjipos2pointer(code, self->mP, n);
+
+    return (*self->mP) != 0;
+}
+
