@@ -14,6 +14,7 @@
 #include "saphire.h"
 #include "saphire_inner.h"
 
+// スペースを飛ばす
 static void skip_spaces(char** p, string_obj* not_evaled)
 {
     while(**p == ' ' || **p == '\t') {
@@ -25,7 +26,7 @@ static void skip_spaces(char** p, string_obj* not_evaled)
 // {}, <>, (), []内を丸ごと取りたい関数。ネストしていてもOK
 // 中身はもう一度parseされる
 // 変数展開も対応
-BOOL read_until_next_close_character(char first_char, char last_char, char** p, string_obj* not_evaled, int* read_end_of_statment, BOOL line_inc, char* sname, int* sline)
+static BOOL read_until_next_close_character(char first_char, char last_char, char** p, string_obj* not_evaled, int* read_end_of_statment, BOOL line_inc, char* sname, int* sline)
 {
     if(**p == first_char) {
         string_push_back2(not_evaled, **p);
@@ -92,7 +93,7 @@ BOOL read_until_next_close_character(char first_char, char last_char, char** p,
             }
             else if(squote || dquote) {
                 if(**p == 0) {
-                    err_msg("require ' or \"", sname, *sline);
+                    err_msg("require ' or \" before the end of source", sname, *sline);
                     return FALSE;
                 }
                 else {
@@ -141,7 +142,7 @@ BOOL read_until_next_close_character(char first_char, char last_char, char** p,
 
 // ブロックを取りたい関数 contentsに入る。
 // 中身はもう一回パースされる
-// 環境変数は対応しない
+// コマンド展開は対応しない
 static BOOL read_block(char** p, string_obj* contents, vector_obj* args, string_obj* not_evaled, BOOL line_inc, char* sname, int* sline)
 {
     int line_of_head = *sline;
@@ -359,14 +360,15 @@ static BOOL read_one_argument(char** p, string_obj* buf, string_obj* not_evaled,
 {
     /// 単語の区切り記号かどうかのテーブル 127以下なら
     static unsigned char table[] = { 
-    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0,
-    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-    1, 0, 0, 0, 0, 0, 1, 0, 1, 1, 1, 0, 0, 0, 0, 0, 
-    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 1, 1, 
-    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 
-    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0 };
+        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0,
+        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
+        1, 0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 0, 0, 0, 0, 
+        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 1, 0, 
+        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
+        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 
+        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
+        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0 
+    };
 
     BOOL squote = FALSE;
     BOOL dquote = FALSE;
@@ -377,6 +379,7 @@ static BOOL read_one_argument(char** p, string_obj* buf, string_obj* not_evaled,
 
             return FALSE;
         }
+
         /// 空文字
         if(!squote && !dquote && **p == '"' && *(*p+1) == '"') {
             break;
@@ -408,6 +411,14 @@ static BOOL read_one_argument(char** p, string_obj* buf, string_obj* not_evaled,
 
             (*p)+=2;
         }
+        else if(**p == '\\' && *(*p+1) == 'a') {
+            string_push_back2(not_evaled, **p);
+            string_push_back2(not_evaled, *(*p+1));
+
+            string_push_back2(buf, '\a');
+
+            (*p)+=2;
+        }
         else if(!squote && !dquote && **p == '\\') {
             string_push_back2(not_evaled, **p);
             (*p)++;
@@ -532,6 +543,18 @@ static BOOL read_one_argument(char** p, string_obj* buf, string_obj* not_evaled,
                 break;
             }
         }
+        // ->は下で処理
+        else if(command && vector_size(command->mArgs) == 0 && **p == '-' && *(*p+1) == '>') {
+            string_push_back2(not_evaled, **p);
+            string_push_back2(buf, **p);
+
+            (*p)++;
+
+            string_push_back2(not_evaled, **p);
+            string_push_back2(buf, **p);
+
+            (*p)++;
+        }
         /// utf-8キャラクター
         else if(((unsigned char)**p) > 127) {
             string_push_back2(not_evaled, **p);
@@ -547,18 +570,6 @@ static BOOL read_one_argument(char** p, string_obj* buf, string_obj* not_evaled,
         else if(**p == '%' && (*(*p+1) == '>' || *(*p+1) == '2')) {
             break;
         }
-        // ->は下で処理
-        else if(command && vector_size(command->mArgs) == 0 && **p == '-' && *(*p+1) == '>') {
-            string_push_back2(not_evaled, **p);
-            string_push_back2(buf, **p);
-
-            (*p)++;
-
-            string_push_back2(not_evaled, **p);
-            string_push_back2(buf, **p);
-
-            (*p)++;
-        }
         else if(table[**p]) {
             break;
         }
@@ -1243,6 +1254,7 @@ static BOOL read_command(char** p, sCommand* command, sStatment* statment, strin
 
                 vector_add(command->mArgs, sArg_new(8, statments));
             }
+            /// リダイレクト
             else if(*(*p+1) == '>') {
                 string_push_back(not_evaled, ">>");
                 (*p)+=2;
@@ -1267,6 +1279,7 @@ static BOOL read_command(char** p, sCommand* command, sStatment* statment, strin
                         , sRedirect_new(type, fd, string_c_str(fname)));
 
             }
+            /// リダイレクト
             else {
                 string_push_back(not_evaled, ">");
                 (*p)++;
@@ -1449,6 +1462,7 @@ static BOOL read_command(char** p, sCommand* command, sStatment* statment, strin
 
                 vector_add(command->mArgs, sArg_new(6, statments));
             }
+            /// リダイレクト
             else {
                 (*p)++;
                 string_push_back(not_evaled, "<");
@@ -1556,7 +1570,7 @@ static BOOL read_command(char** p, sCommand* command, sStatment* statment, strin
             }
             else {
                 char buf[128];
-                snprintf(buf, 128, "unexpected token -->%c\n", **p);
+                snprintf(buf, 128, "unexpected token1 -->%c\n", **p);
                 err_msg(buf, sname, *sline);
                 return FALSE;
             }
@@ -1591,7 +1605,7 @@ static BOOL read_command(char** p, sCommand* command, sStatment* statment, strin
             }
             else {
                 char buf[128];
-                snprintf(buf, 128, "unexpected token -->%c\n", **p);
+                snprintf(buf, 128, "unexpected token2 -->%c\n", **p);
                 err_msg(buf, sname, *sline);
                 return FALSE;
             }
@@ -1838,7 +1852,7 @@ BOOL parse(char* cmdline, char* sname, int* sline, sStatments* statments)
         }
         else {
             char buf[128];
-            snprintf(buf, 128, "unexpected token -->%c\n", *p);
+            snprintf(buf, 128, "unexpected token3 -->%c\n", *p);
             err_msg(buf, sname, *sline);
             return FALSE;
         }
@@ -1857,7 +1871,6 @@ BOOL parse(char* cmdline, char* sname, int* sline, sStatments* statments)
     return TRUE;
 }
 
-
 // 文字列をクォートして返す
 static BOOL expand_env_get_quoted_str(char* fname, string_obj* quoted_fname, char* sname, int* sline)
 {
@@ -1880,6 +1893,10 @@ static BOOL expand_env_get_quoted_str(char* fname, string_obj* quoted_fname, cha
             string_push_back(quoted_fname, "\\t");
             p++;
         }
+        else if(*p == '\a') {
+            string_push_back(quoted_fname, "\\a");
+            p++;
+        }
         else if(*p==' ' || *p=='*' || *p=='&' || *p=='~'
                 || *p=='#' || *p =='$' || *p=='(' || *p==')'
                 || *p=='\\' || *p=='|' || *p=='[' || *p==']' || *p=='{' 
@@ -2121,7 +2138,7 @@ BOOL saphire_compile(char* fname, char* out_fname)
 
     sStatments_save(statments, fd);
 
-    close(fd);
+    (void)close(fd);
 
     return TRUE;
 }
