@@ -844,6 +844,9 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
 
                 // スタックを掘る
                 vector_add(gStackFrame, HASH_NEW(30));
+                vector_add(gStackFramePointers, HASH_NEW(30));
+                vector_add(gStackFrameHashs, HASH_NEW(30));
+                vector_add(gStackFrameArrays, HASH_NEW(30));
 
                 sObject* object2 = sObject_new(objname, object);
                 if(object) {
@@ -861,6 +864,9 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
 
                 // スタックを埋める
                 vector_pop_back(gStackFrame);
+                vector_pop_back(gStackFrameArrays);
+                vector_pop_back(gStackFrameHashs);
+                vector_pop_back(gStackFramePointers);
 
                 /// スタックフレームの記録を消す
                 string_obj* sname_strace = vector_pop_back(gStackTraceFName);
@@ -903,6 +909,9 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
 
                 // スタックを掘る
                 vector_add(gStackFrame, HASH_NEW(30));
+                vector_add(gStackFramePointers, HASH_NEW(30));
+                vector_add(gStackFrameHashs, HASH_NEW(30));
+                vector_add(gStackFrameArrays, HASH_NEW(30));
 
                 if(object) {
                     klass = hash_item(object->mClasses, klassname);
@@ -935,6 +944,9 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
 
                 // スタックを埋める
                 vector_pop_back(gStackFrame);
+                vector_pop_back(gStackFrameArrays);
+                vector_pop_back(gStackFrameHashs);
+                vector_pop_back(gStackFramePointers);
 
                 /// スタックフレームの記録を消す
                 string_obj* sname_strace = vector_pop_back(gStackTraceFName);
@@ -968,6 +980,9 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
 
                 // スタックを掘る
                 vector_add(gStackFrame, HASH_NEW(30));
+                vector_add(gStackFramePointers, HASH_NEW(30));
+                vector_add(gStackFrameHashs, HASH_NEW(30));
+                vector_add(gStackFrameArrays, HASH_NEW(30));
 
                 sBlock* block = vector_item(blocks, 0);
                 sStatments* statments = block->mStatments;
@@ -980,6 +995,9 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
 
                 // スタックを埋める
                 vector_pop_back(gStackFrame);
+                vector_pop_back(gStackFrameArrays);
+                vector_pop_back(gStackFrameHashs);
+                vector_pop_back(gStackFramePointers);
 
                 /// スタックフレームの記録を消す
                 string_obj* sname_strace = vector_pop_back(gStackTraceFName);
@@ -1037,6 +1055,9 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
                 hash_put(object2->mArrays, "ARGV", fun_argv);
 
                 vector_add(gStackFrame, HASH_NEW(30));
+                vector_add(gStackFramePointers, HASH_NEW(30));
+                vector_add(gStackFrameHashs, HASH_NEW(30));
+                vector_add(gStackFrameArrays, HASH_NEW(30));
             }
             /// 引数名が指定されていなければスタックフレームは増やさない
             else {
@@ -1080,7 +1101,10 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
 
             if(strcmp(string_c_str(method->arg_name), "") == 0) {
                 /// スタックを消す ///
-                hash_obj* stack = vector_pop_back(gStackFrame);
+                vector_pop_back(gStackFrame);
+                vector_pop_back(gStackFrameArrays);
+                vector_pop_back(gStackFrameHashs);
+                vector_pop_back(gStackFramePointers);
 
                 /// 引数を消す ///
                 hash_erase(object2->mArrays, "ARGV");
@@ -1149,6 +1173,9 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
                 hash_put(gArrays, "ARGV", fun_argv);
 
                 vector_add(gStackFrame, HASH_NEW(30));
+                vector_add(gStackFramePointers, HASH_NEW(30));
+                vector_add(gStackFrameHashs, HASH_NEW(30));
+                vector_add(gStackFrameArrays, HASH_NEW(30));
             }
             /// 引数名が指定されていなければスタックフレームは増やさない
             else {
@@ -1191,7 +1218,10 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
 
             if(strcmp(string_c_str(fun->arg_name), "") == 0) {
                 /// スタックを消す ///
-                hash_obj* stack = vector_pop_back(gStackFrame);
+                vector_pop_back(gStackFrame);
+                vector_pop_back(gStackFrameArrays);
+                vector_pop_back(gStackFrameHashs);
+                vector_pop_back(gStackFramePointers);
 
                 /// 引数を消す ///
                 hash_erase(gArrays, "ARGV");
